@@ -59,53 +59,54 @@ class Pandora:
                 install_opener(opener)
 
         def sync( self ):
-		reqUrl = self.base_url_rid %( self.rid, "sync" )
+                new_version = self.protocol_version
+		while True:
+		        reqUrl = self.base_url_rid %( self.rid, "sync" )
 
-		req = xmlrpclib.dumps( (), "misc.sync" ).replace( "\n", "" )
-		enc = crypt.encryptString( req, self.keys['out'] )
+			req = xmlrpclib.dumps( (), "misc.sync" ).replace( "\n", "" )
+			enc = crypt.encryptString( req, self.keys['out'] )
 
-		u = urlopen( reqUrl, enc )
-		resp = u.read()
-		u.close()
+			u = urlopen( reqUrl, enc )
+			resp = u.read()
+                        if resp.find('INCOMPATIBLE_VERSION')>0:
+                            new_version = new_version+1
+                            if new_version - self.protocol_version < 15:
+                                    print "INCOMPATIBLE VERSION DETECTED, BUMPING."
+                                    self.base_url = "https://www.pandora.com/radio/xmlrpc/v%d?" %(new_version)
+                                    self.base_url_rid = self.base_url + "rid=%sP&method=%s"
+                                    self.base_url_lid = self.base_url + "rid=%sP&lid=%s&method=%s"
+                                    continue
+                            else:
+                                    return False
+			u.close()
 
-		parsed = xmlrpclib.loads( resp )[0][0]
-		t = crypt.decryptString( parsed, self.keys['in'] )
-		self.offset = _inttime() - int(t[4:-2])
+			parsed = xmlrpclib.loads( resp )[0][0]
+			t = crypt.decryptString( parsed, self.keys['in'] )
+			self.offset = _inttime() - int(t[4:-2])
+                	self.protocol_version=new_version
+			return True
 
         def authListener( self, user, pwd ):
-                new_version = self.protocol_version
-                while True:
-                        reqUrl = self.base_url_rid %( self.rid, "authenticateListener" )
-                        req = xmlrpclib.dumps( ( self._timestamp(), user, pwd, 'html5tuner', '', '', 'HTML5', True ), "listener.authenticateListener" )
-                        req = req.replace( "\n", "" )
-                        enc = crypt.encryptString( req, self.keys['out'] )
-                        try:
-                                u = urlopen( reqUrl, enc )
-                                resp = u.read()
-                                if resp.find('INCOMPATIBLE_VERSION')>0:
-                                    new_version = new_version+1
-                                    if new_version - self.protocol_version < 15:
-                                            print "INCOMPATIBLE VERSION DETECTED, BUMPING."
-                                            self.base_url = "https://www.pandora.com/radio/xmlrpc/v%d?" %(new_version)
-                                            self.base_url_rid = self.base_url + "rid=%sP&method=%s"
-                                            self.base_url_lid = self.base_url + "rid=%sP&lid=%s&method=%s"
-                                            continue
-                                    else:
-                                            return False
-                                u.close()
-                        except:
-                                return False
-                        try:
-                                parsed = xmlrpclib.loads( resp )[0][0]
-                        except xmlrpclib.Fault, fault:
-                                print "Error:", fault.faultString
-                                print "Code:", fault.faultCode
-                                return False
+                reqUrl = self.base_url_rid %( self.rid, "authenticateListener" )
+                req = xmlrpclib.dumps( ( self._timestamp(), user, pwd, 'html5tuner', '', '', 'HTML5', True ), "listener.authenticateListener" )
+                req = req.replace( "\n", "" )
+                enc = crypt.encryptString( req, self.keys['out'] )
+                try:
+                        u = urlopen( reqUrl, enc )
+                        resp = u.read()
+                        u.close()
+                except:
+                        return False
+                try:
+                        parsed = xmlrpclib.loads( resp )[0][0]
+                except xmlrpclib.Fault, fault:
+                        print "Error:", fault.faultString
+                        print "Code:", fault.faultCode
+                        return False
 
-                        self.authToken = parsed["authToken"]
-                        self.lid = parsed["listenerId"]
-                        self.protocol_version=new_version
-                        return True
+                self.authToken = parsed["authToken"]
+                self.lid = parsed["listenerId"]
+                return True
 
         def getStations( self ):
                 reqUrl = self.base_url_lid %( self.rid, self.lid, "getStations" )
@@ -138,8 +139,8 @@ class Pandora:
 
                 reqUrl = self.base_url_lid %( self.rid, self.lid, "addFeedback" )
 
-                args = ( self._timestamp(), self.authToken, stationId, song[1]["musicId"], \
-                        song[1]["matchingSeed"], song[1]["userSeed"], song[1]["focusTraitId"], '', rating, False )
+                args = ( self._timestamp(), self.authToken, stationId, song[1]["trackToken"], \
+                        rating )
 
                 req = xmlrpclib.dumps( args, "station.addFeedback" )
                 req = req.replace( "\n", "" )
