@@ -3,9 +3,9 @@
 import os
 import sys,time,re
 import webbrowser
-from PySide import QtGui,QtCore
-from PySide.QtCore import *
-from PySide.QtGui import *
+from PyQt4 import QtGui,QtCore
+from PyQt4.QtCore import *
+from PyQt4.QtGui import *
 from pyRadio_ui import *
 from pyRadio_ui_portrait import *
 from radioplayer import RadioPlayer
@@ -114,12 +114,12 @@ class Panda(QtGui.QMainWindow): #main class
 		self.player.format = self.c.format
 		self.player.protocol_version = int(self.c.protocol_version)
 		self.player.proxy = self.c.proxy
-		self.player.start()
 		if not self.c.lastplayed == "": #auto-play last station
 			self.autoPlay = self.c.lastplayed
 		else:
 			self.autoPlay = 0
 		self.connect_signals() #called every time orientation changes to connect slots
+		self.player.start()
 		self.stimer.singleShot(100, self.auth)
 		self.doFM(True)
 		try: #test for rotation and set auto-rotation on
