@@ -2,7 +2,7 @@
 import sys,os
 
 from libpiano.pandora import Pandora
-from PySide import QtCore
+from PyQt4 import QtCore
 
 class RadioPlayer(QtCore.QThread): #Main radio class
 	def __init__( self, Parent=None ):
@@ -21,8 +21,10 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 			from libpiano.OSSOBackend import OSSOBackend
 			self.player = OSSOBackend()
 		else:
-			from libpiano.GstBackend import GstBackend
-			self.player = GstBackend()
+			#from libpiano.MPlayerBackend import MPlayerBackend
+			#self.player = MPlayerBackend()
+			from libpiano.OSSOBackend import OSSOBackend
+			self.player = OSSOBackend()
 
 		QtCore.QObject.connect(self.player, QtCore.SIGNAL("eof"), self.sigEOF)
 		QtCore.QObject.connect(self.player, QtCore.SIGNAL("state_change(int)"), self.stateChange)
@@ -30,7 +32,6 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 		self.format = 'aacplus'
 		self.protocol_version = 0
 		self.proxy = ""
-		self.pandora = None
 
 		QtCore.QThread.__init__(self)
 
@@ -136,6 +137,7 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 			"stationId"	: s["stationId"], \
 			"identity"	: s["identity"], \
 			"musicId"	: s["musicId"], \
+			"trackToken"	: s["trackToken"], \
 			"artistMusicId" : s["artistMusicId"] }
 			items.append( ( s["audioURL"], item ) )
 		self.playlist.extend( items )
